@@ -4,7 +4,6 @@ try:
 except ImportError:
     import pickle
 import logging
-import socket
 import sys
 import traceback as traceback_mod
 import urllib
@@ -29,7 +28,7 @@ class SentryClient(object):
             kwargs = filter_(None).process(kwargs) or kwargs
 
         kwargs.setdefault('level', logging.ERROR)
-        kwargs.setdefault('server_name', socket.gethostname())
+        kwargs.setdefault('server_name', settings.NAME)
 
         checksum = construct_checksum(**kwargs)
 
@@ -43,20 +42,21 @@ class SentryClient(object):
 
     def send(self, **kwargs):
         if settings.REMOTE_URL:
-            data = {
-                'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
-                'key': settings.KEY,
-            }
-            req = urllib2.Request(settings.REMOTE_URL, urllib.urlencode(data))
+            for url in settings.REMOTE_URL:
+                data = {
+                    'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
+                    'key': settings.KEY,
+                }
+                req = urllib2.Request(url, urllib.urlencode(data))
 
-            try:
-                response = urllib2.urlopen(req, None, settings.REMOTE_TIMEOUT).read()
-            except urllib2.URLError, e:
-                logger.critical('Unable to reach Sentry log server')
-                logger.log(kwargs.pop('level', None) or logging.ERROR, kwargs.pop('message', None))
-            except urllib2.HTTPError, e:
-                logger.critical('Unable to reach Sentry log server', extra={'body': e.read()})
-                logger.log(kwargs.pop('level', None) or logging.ERROR, kwargs.pop('message', None))
+                try:
+                    response = urllib2.urlopen(req, None, settings.REMOTE_TIMEOUT).read()
+                except urllib2.URLError, e:
+                    logger.exception('Unable to reach Sentry log server: %s' % (e,), extra={'remote_url': url})
+                    logger.log(kwargs.pop('level', None) or logging.ERROR, kwargs.pop('message', None))
+                except urllib2.HTTPError, e:
+                    logger.exception('Unable to reach Sentry log server: %s' % (e,), extra={'body': e.read(), 'remote_url': url})
+                    logger.log(kwargs.pop('level', None) or logging.ERROR, kwargs.pop('message', None))
         else:
             from sentry.models import GroupedMessage
             
@@ -149,4 +149,5 @@ class SentryClient(object):
             traceback=tb_message,
             data=data,
             **kwargs
-        )
\ No newline at end of file
+        )
+
