@@ -135,10 +135,13 @@ class GroupedMessage(MessageBase):
         if engine.startswith('postgresql'):
             return 'times_seen / (pow((floor(extract(epoch from now() - last_seen) / 3600) + 2), 1.25) + 1)'
         if engine.startswith('mysql'):
-            return 'times_seen / (pow((floor(unix_timestamp(now() - last_seen) / 3600) + 2), 1.25) + 1)'
+            return 'times_seen / (pow((floor((unix_timestamp(now()) - unix_timestamp(last_seen)) / 3600) + 2), 1.25) + 1)'
         return 'times_seen'
 
     def mail_admins(self, request=None, fail_silently=True):
+        if not settings.ADMINS:
+            return
+        
         from django.core.mail import send_mail
         from django.template.loader import render_to_string
 
@@ -221,4 +224,4 @@ class Message(MessageBase):
         else:
             fake_request.path_info = ''
         fake_request.path = fake_request.path_info
-        return fake_request
\ No newline at end of file
+        return fake_request
