@@ -484,6 +484,24 @@ class SentryTestCase(TestCase):
         
         settings.MIDDLEWARE_CLASSES = orig
 
+    def testSettingName(self):
+        orig = settings.NAME
+        settings.NAME = 'foo'
+        
+        self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc'))
+
+        self.assertEquals(Message.objects.count(), 1)
+        self.assertEquals(GroupedMessage.objects.count(), 1)
+        last = Message.objects.get()
+        self.assertEquals(last.logger, 'root')
+        self.assertEquals(last.class_name, 'Exception')
+        self.assertEquals(last.level, logging.ERROR)
+        self.assertEquals(last.message, 'view exception')
+        self.assertEquals(last.server_name, 'foo')
+        self.assertEquals(last.view, 'sentry.tests.views.raise_exc')
+        
+        settings.NAME = orig
+
 class SentryViewsTest(TestCase):
     urls = 'sentry.tests.urls'
     fixtures = ['sentry/tests/fixtures/views.json']
@@ -566,7 +584,7 @@ class RemoteSentryTest(TestCase):
     
     def setUp(self):
         self.server_thread = None
-        settings.REMOTE_URL = 'http://localhost:8000%s' % reverse('sentry-store')
+        settings.REMOTE_URL = ['http://localhost:8000%s' % reverse('sentry-store')]
         logger = logging.getLogger('sentry')
         for h in logger.handlers:
             logger.removeHandler(h)
@@ -653,7 +671,7 @@ class SentryMailTest(TestCase):
     urls = 'sentry.tests.urls'
     
     def setUp(self):
-        settings.ADMINS = ((getpass.getuser(), '%s@localhost' % getpass.getuser()),)
+        settings.ADMINS = ('%s@localhost' % getpass.getuser(),)
     
     def test_mail_admins(self):
         group = GroupedMessage.objects.get()
@@ -769,4 +787,5 @@ class SentryClientTest(TestCase):
         
         self.assertEquals(_foo[''].getMessage(), 'view exception')
         self.assertEquals(_foo[''].levelno, client.default_level)
-        self.assertEquals(_foo[''].class_name, 'Exception')
\ No newline at end of file
+        self.assertEquals(_foo[''].class_name, 'Exception')
+
