@@ -12,6 +12,7 @@ try:
 except ImportError:
     SimpleLineChart = None
 
+from django.conf import settings as dj_settings
 from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
 from django.db.models import Count
@@ -24,9 +25,10 @@ from django.utils.safestring import mark_safe
 from django.views.decorators.csrf import csrf_protect, csrf_exempt
 
 from sentry import settings
+from sentry.helpers import get_db_engine
 from sentry.models import GroupedMessage, Message
 from sentry.templatetags.sentry_helpers import with_priority
-from sentry.reporter import ImprovedExceptionReporter, FakeRequest
+from sentry.reporter import ImprovedExceptionReporter
 
 from indexer.models import Index
 
@@ -56,10 +58,8 @@ def get_filters():
 def login_required(func):
     def wrapped(request, *args, **kwargs):
         if not request.user.is_authenticated():
-            print "not authed"
             return HttpResponseRedirect(reverse('sentry-login'))
         if not request.user.has_perm('sentry_groupedmessage.can_view'):
-            print "no perms"
             return HttpResponseRedirect(reverse('sentry-login'))
         return func(request, *args, **kwargs)
     wrapped.__doc__ = func.__doc__
@@ -169,7 +169,7 @@ def group(request, group_id):
 
     message_list = group.message_set.all()
     
-    obj = message_list[0]
+    obj = message_list.order_by('-id')[0]
     if '__sentry__' in obj.data:
         module, args, frames = obj.data['__sentry__']['exc']
         obj.class_name = str(obj.class_name)
@@ -179,19 +179,7 @@ def group(request, group_id):
 
         exc_value.args = args
     
-        fake_request = FakeRequest()
-        fake_request.META = obj.data.get('META', {})
-        fake_request.GET = obj.data.get('GET', {})
-        fake_request.POST = obj.data.get('POST', {})
-        fake_request.FILES = obj.data.get('FILES', {})
-        fake_request.COOKIES = obj.data.get('COOKIES', {})
-        fake_request.url = obj.url
-        if obj.url:
-            fake_request.path_info = '/' + obj.url.split('/', 3)[-1]
-        else:
-            fake_request.path_info = ''
-
-        reporter = ImprovedExceptionReporter(fake_request, exc_type, exc_value, frames, obj.data['__sentry__'].get('template'))
+        reporter = ImprovedExceptionReporter(obj.request, exc_type, exc_value, frames, obj.data['__sentry__'].get('template'))
         traceback = mark_safe(reporter.get_traceback_html())
     elif group.traceback:
         traceback = mark_safe('<pre>%s</pre>' % (group.traceback,))
@@ -200,7 +188,8 @@ def group(request, group_id):
     
     unique_servers = message_list.filter(server_name__isnull=False).values_list('server_name', 'logger', 'view', 'checksum').annotate(times_seen=Count('server_name')).values('server_name', 'times_seen').order_by('-times_seen')
     
-    if SimpleLineChart:
+    engine = get_db_engine()
+    if SimpleLineChart and not engine.startswith('sqlite'):
         today = datetime.datetime.now()
 
         chart_qs = message_list\
@@ -214,7 +203,7 @@ def group(request, group_id):
         else:
             max_y = 1
 
-        chart = SimpleLineChart(384, 80, y_range=[0, max_y])
+        chart = SimpleLineChart(300, 80, y_range=[0, max_y])
         chart.add_data([max_y]*30)
         chart.add_data([rows.get((today-datetime.timedelta(hours=d)).hour, 0) for d in range(0, 24)][::-1])
         chart.add_data([0]*30)
